@@ -1384,11 +1384,9 @@ class FilterSeries(FilterSeriesBase):
                 still_needed = [req for req in still_needed if not req.allows(quality)]
         return bool(downloaded_qualities)
 
-    # Run last, to make sure output plugins haven't failed the entry
-    @plugin.priority(-255)
-    def on_task_output(self, task, config):
+    def on_task_learn(self, task, config):
         """Learn succeeded episodes"""
-        log.debug('on_task_output')
+        log.debug('on_task_learn')
         for entry in task.accepted:
             if 'series_releases' in entry:
                 for release in entry['series_releases']:
